#include <windows.h>
#include <stdio.h>
#include <stdlib.h>
#pragma hdrstop
#include "nt95delayload.h"



void ShowSessionList( const char *server, const char *client, const char *user )
{
	OSVERSIONINFO ovi = { sizeof ovi };
	SessionList sl = { 0, 0, NULL };
	int i;

	GetVersionEx( &ovi );
	switch ( ovi.dwPlatformId )
	{
		case VER_PLATFORM_WIN32_WINDOWS:
			FillSessionList95( server, client, user, sl );
			break;
		case VER_PLATFORM_WIN32_NT:
			FillSessionListNT( server, client, user, sl );
			break;
		default:
			puts( "Sorry, but this sample requires Windows 9x or NT." );
			exit( 1 );
	}

	printf( "%-30.30s %-30.30s %-8.8s\n", "Client", "User", "Idle sec" );
	printf( "%-30.30s %-30.30s %-8.8s\n", "------------------------------",
		"------------------------------", "--------" );

	for ( i = 0; i < sl.nUsed; ++ i )
	{
		printf( "%-30.30s %-30.30s %02d:%02d:%02d\n",
			sl.s[i].client == NULL? "": sl.s[i].client,
			sl.s[i].user == NULL? "": sl.s[i].user,
			sl.s[i].time / 3600, ( sl.s[i].time % 3600 ) / 60, sl.s[i].time % 60 );
		free( sl.s[i].client );
		free( sl.s[i].user );
	}

	free( sl.s );
}



int main( int argc, char *argv[] )
{
	const char *server = NULL, *user = NULL, *client = NULL;
	int errors = 0, i;
	bool haveServer = false, haveUser = false, haveClient = false;

	if ( argc > 7 )
	{
usage:
		puts( "\nnsesse2 [-s \\\\server] [-c \\\\computername|-u username]\n" );
		puts( "\\\\server -- machine to check, with backslashes, please." );
		puts( "  Default: local machine.\n" );
		puts( "\\\\computername -- only list sessions from this computer." );
		puts( "  Default: all computers.\n" );
		puts( "username -- only list sessions logged in as username." );
		puts( "  Default: all users.\n" );
		puts( "You can use -c, or -u, or neither -- but not both together." );
		puts( "On Win9X, both -c and -u will be ignored." );
		return 1;
	}

	for ( i = 1; i < argc; ++ i )
	{
		if ( *argv[i] != '-' && *argv[1] != '/' )
		{
			printf( "\"%s\": switches must start with a dash or a slash.\n",
				argv[i] );
			++ errors;
			continue;
		}

		switch ( argv[i][1] )
		{
			case '?':
				goto usage;
			case 's':
				if ( i == argc - 1 ) // no further args?
				{
					printf( "\"%s\" requires the server name as an argument.\n", argv[i] );
					++ errors;
					break;
				}
				if ( haveServer )
				{
					printf( "\"%s\" can only be used once.\n", argv[i] );
					++ errors;
					++ i; // skip what probably is another server name
					break;
				}
				++ i; // advance arg index to account for server name
				server = argv[i];
				haveServer = true;
				break;
			case 'c':
				if ( i == argc - 1 ) // no further args?
				{
					printf( "\"%s\" requires the client name as an argument.\n", argv[i] );
					++ errors;
					break;
				}
				if ( haveClient )
				{
					printf( "\"%s\" can only be used once.\n", argv[i] );
					++ i;
					++ errors;
					break;
				}
				++ i;
				client = argv[i];
				haveClient = true;
				if ( client[0] != '\\' || client[1] != '\\' )
				{
					printf( "\"%s\" should start with a double backslash \"\\\\\".\n", client );
					++ errors;
				}
				break;
			case 'u':
				if ( i == argc - 1 ) // no further args?
				{
					printf( "\"%s\" requires the user name as an argument.\n", argv[i] );
					++ errors;
					break;
				}
				if ( haveUser )
				{
					printf( "\"%s\" can only be used once.\n", argv[i] );
					++ i;
					++ errors;
					break;
				}
				++ i;
				user = argv[i];
				haveUser = true;
				break;
			default:
				printf( "\"%s\" is not a valid switch, sorry.\n", argv[i] );
				++ errors;
				break;
		}
	}

	if ( errors )
	{
		printf( "\n%d command line errors. Pass GO, do not collect $200.\n\n",
			errors );
		goto usage;
	}

	ShowSessionList( server, client, user );

	return i;
}
